// Handle for system info object
var systeminfo;
var bytesPerKb = 1024;
var refreshInterval = 30000; // 30s
var barWidth = 120; // in pixels
var refreshTimer;
var serviceObj = null;

/**
 * Setting default data on application load
 */
function init() {
    window.widget.prepareForTransition("fade");

    // Receiving systeminfo variable
    document.getElementById("status_image").src="gfx/status_activating.png";
    try{
        systeminfo = document.embeds[0];
    } catch (err){
        document.getElementById("status_image").src="gfx/status_deactive.png";
        return;
    }

    // Obtain the AppManager service object
    try {
        serviceObj = device.getServiceObject("Service.AppManager", "IAppManager");
    } catch (ex) {
        document.getElementById("status_image").src="gfx/status_deactive.png";
        return;
    }

    if (widget.isrotationsupported)
    {
        widget.setDisplayPortrait();
    }

    // Start displaying menu
    //menu.showSoftkeys();
    window.menu.hideSoftkeys();
    window.widget.performTransition();

    // Start the graphics
    updateNow();
}

widget.onshow = function()
{
    updateNow();
}

winget.onhide = function()
{
    if (refreshTimer != undefined)
    {
        clearTimeout(refreshTimer);
    }
}


function update()
{
    var memUsagePercent = Math.ceil(((systeminfo.totalram-systeminfo.freeram)/systeminfo.totalram) * 100);
    var phoneMemPercent = getDriveInfo(0);
    var massMemPercent = getDriveInfo(1);
    var memCardPercent = getDriveInfo(2);

    updateMemoryBar(memUsagePercent);

    // TODO: hide non-existing drives in else clauses
    if (phoneMemPercent != -1)
    {
        updatePhoneMemBar(phoneMemPercent);
    }
    if (massMemPercent != -1)
    {
        updateMassMemBar(massMemPercent);
        document.getElementById("massmem_div").style.display="inline";
    }
    else
    {
        document.getElementById("massmem_div").style.display="none";
    }
    if (memCardPercent != -1)
    {
        updateMemCardBar(memCardPercent);
        document.getElementById("memcard_div").style.display="inline";
    }
    else
    {
        document.getElementById("memcard_div").style.display="none";
    }

    setTextualValues();

    if (refreshTimer != undefined)
    {
        clearTimeout(refreshTimer);
    }
    refreshTimer = setTimeout("update()", refreshInterval);
    document.getElementById("status_image").src="gfx/status_active.png";
}

function updateNow()
{
    document.getElementById("status_image").src="gfx/status_activating.png";
    if (refreshTimer != undefined)
    {
        clearTimeout(refreshTimer);
    }
    update();
}

function updateMemoryBar(percentage)
{
    var control = document.getElementById('dvShow')
    var percentWidth = barWidth * (percentage/100);
    percentWidth = Math.ceil(percentWidth);

	var dvPercentWidth = document.getElementById('memory_bar_center');
    dvPercentWidth.style.width = percentWidth.toString() + 'px';
    setBarColor(percentage, dvPercentWidth);

    var sPercent = document.createTextNode(percentage.toString() + "%");

    var textValue = document.getElementById("memory_value");
    textValue.innerHTML= percentage+"%";
}

function updatePhoneMemBar(percentage)
{
    var control = document.getElementById('dvShow')
    var percentWidth = barWidth * (percentage/100);
    percentWidth = Math.ceil(percentWidth);

	var dvPercentWidth = document.getElementById('phonemem_bar_center');
    dvPercentWidth.style.width = percentWidth.toString() + 'px';
    setBarColor(percentage, dvPercentWidth);

    var sPercent = document.createTextNode(percentage.toString() + "%");

    var textValue = document.getElementById("phonemem_value");
    textValue.innerHTML= percentage+"%";
}

function updateMassMemBar(percentage)
{
    var control = document.getElementById('dvShow')
    var percentWidth = barWidth * (percentage/100);
    percentWidth = Math.ceil(percentWidth);

	var dvPercentWidth = document.getElementById('massmem_bar_center');
    dvPercentWidth.style.width = percentWidth.toString() + 'px';
    setBarColor(percentage, dvPercentWidth);

    var sPercent = document.createTextNode(percentage.toString() + "%");

    var textValue = document.getElementById("massmem_value");
    textValue.innerHTML= percentage+"%";
}

function updateMemCardBar(percentage)
{
    var control = document.getElementById('dvShow')
    var percentWidth = barWidth * (percentage/100);
    percentWidth = Math.ceil(percentWidth);

	var dvPercentWidth = document.getElementById('memcard_bar_center');
    dvPercentWidth.style.width = percentWidth.toString() + 'px';
    setBarColor(percentage, dvPercentWidth);

    var sPercent = document.createTextNode(percentage.toString() + "%");

    var textValue = document.getElementById("memcard_value");
    textValue.innerHTML= percentage+"%";
}

function getDriveInfo(driveNumber)
{
    var returnValue = -1;

    // Getting drivelist and splitting it into array
    var drivesStr = systeminfo.drivelist;
    if(drivesStr == undefined) {
        return;
    }

    var drives = drivesStr.split(" ");
    var drivesCount = drives.length;

    if (drivesCount >= driveNumber && systeminfo.drivesize(drives[driveNumber]) > 0)
    {
        var driveSize = systeminfo.drivesize(drives[driveNumber]) / bytesPerKb;
        var driveFree = systeminfo.drivefree(drives[driveNumber]) / bytesPerKb;
        var returnValue = Math.ceil(((driveSize-driveFree)/driveSize) * 100);
    }
    return returnValue;
}

function setBarColor(percentage, barObject)
{
    var newImage;
    if (percentage > 90)
    {
        newImage = 'gfx/meter_red.png';
    }
    else if (percentage > 70)
    {
        newImage = 'gfx/meter_orange.png';
    }
    else if (percentage > 50)
    {
        newImage = 'gfx/meter_yellow.png';
    }
    else
    {
        newImage = 'gfx/meter_green.png';
    }
    if (barObject.style.backgroundImage.indexOf(newImage) < 0)
    {
        barObject.style.backgroundImage = 'url('+newImage+')';
    }
}

function setTextualValues()
{
    document.getElementById("text_mem_free").innerHTML=Math.ceil((systeminfo.totalram-systeminfo.freeram)/bytesPerKb / 1000);
    document.getElementById("text_mem_total").innerHTML=Math.ceil(systeminfo.totalram/bytesPerKb / 1000);
    document.getElementById("memory_abs_value").innerHTML=Math.ceil(systeminfo.freeram/bytesPerKb / 1000) + " MB";

    var drivesStr = systeminfo.drivelist;
    if(drivesStr == undefined) {
        return;
    }
    var drives = drivesStr.split(" ");
    var drivesCount = drives.length;


    var driveFree = Math.ceil(systeminfo.drivefree(drives[0]) / bytesPerKb / 1000);
    var driveTotal = Math.ceil(systeminfo.drivesize(drives[0]) / bytesPerKb / 1000);

    document.getElementById("text_phonemem_free").innerHTML= driveTotal-driveFree;
    document.getElementById("text_phonemem_total").innerHTML= driveTotal;
    document.getElementById("phonemem_abs_value").innerHTML= driveFree + " MB";

    if (drivesCount >= 1)
    {
        driveFree = Math.ceil(systeminfo.drivefree(drives[1]) / bytesPerKb / 1000);
        driveTotal = Math.ceil(systeminfo.drivesize(drives[1]) / bytesPerKb / 1000);
    }
    else
    {
        driveFree = 0;
        driveTotal = 0;
    }

    document.getElementById("text_massmem_free").innerHTML= driveTotal-driveFree;
    document.getElementById("text_massmem_total").innerHTML= driveTotal;
    document.getElementById("massmem_abs_value").innerHTML= driveFree + " MB";

    if (drivesCount >= 2)
    {
        driveFree = Math.ceil(systeminfo.drivefree(drives[2]) / bytesPerKb / 1000);
        driveTotal = Math.ceil(systeminfo.drivesize(drives[2]) / bytesPerKb / 1000);
    }
    else
    {
        driveFree = 0;
        driveTotal = 0;
    }
    document.getElementById("text_memcard_free").innerHTML= driveTotal-driveFree;
    document.getElementById("text_memcard_total").innerHTML= driveTotal;
    document.getElementById("memcard_abs_value").innerHTML= driveFree + " MB";
}

function launchApplication(buttonName, uid)
{
    var buttonObj = document.getElementById(buttonName);
    buttonObj.style.backgroundImage = 'url(gfx/button2.png)';
    buttonObj.style.borderStyle = "inset";

    var appLaunchedCall = function() { appLaunched(buttonObj, uid); };
    setTimeout(appLaunchedCall, 300);
}

function appLaunched(buttonObj, uid)
{
    var criteria = new Object();
    criteria.ApplicationID = "s60uid://"+uid;
    var result = serviceObj.IAppManager.LaunchApp(criteria);
    if (result.ErrorCode != 0) {
        alert(result.ErrorCode + ": " + result.ErrorMessage);
    }

    buttonObj.style.backgroundImage = 'url(gfx/button1.png)';
    buttonObj.style.borderStyle = "outset";
}

function sendToBackground()
{
	widget.openApplication(0x102750F0);
}

function exitApplication()
{
    window.close();
}
